@@ -1,6 +1,6 @@
 from pydantic import BaseModel
 from typing import Optional
-
+from enum import IntEnum
 
 class AgriculturalProduction(BaseModel):
     id: Optional[int] = None
@@ -51,11 +51,6 @@ class Farm(BaseModel):
     lat: int
     long: int
     altitude: int
-    holderAge: int
-    holderGender: int
-    holderSuccessors: int
-    holderSuccessorsAge: int
-    holderFamilyMembers: int
     regionLevel1: int
     regionLevel1Name: str
     regionLevel2: int
@@ -122,3 +117,93 @@ class PolicyProductGroupRelation(BaseModel):
     productGroupId: int
     policyId: int
     populationId: Optional[int] = None
+
+class HolderFarmYearData(BaseModel):
+    id: Optional[int] = None
+    farmId: Optional[int] = None
+    yearId: Optional[int] = None
+    holderAge: int
+    holderGender: int
+    holderSuccessors: int
+    holderSuccessorsAge: int
+    holderFamilyMembers: int
+
+class ValueToLPDTO(BaseModel):
+    farmId: int
+    yearId: int
+    a_0: float
+    sE465: float
+    sE490: float
+    averageHAPrice: float
+    sE420: float
+    sE410: float
+    aversionRiskFactor: float
+    m_0: float
+
+class ValueFromLPDTO(BaseModel):
+    farmId: int
+    yeardId: int
+    agriculturalLand: float
+    totalCurrentAssests: float
+    agriculturalLandHectaresAdquisition: float
+    longAndMediumTermLoans: float
+    averageHAPrice: float
+
+class CropDataDTO(BaseModel):
+
+    cropProductiveArea: int
+    cropVariableCosts: float
+    cropProduction: float
+    cropSellingPrice: float
+    coupledSubsidy: float
+    uAA: float
+class ValueFromSPDTO(BaseModel):
+
+    farmId: int
+
+    totalCurrentAssets: float
+    farmNetIncome: float
+    farmGrossIncome: float
+    agriculturalLand: float
+    crops: dict[str,CropDataDTO]
+
+class LivestockDTO(BaseModel):
+    numberOfAnimals: float
+    dairyCows: int
+    rebreedingCows: float
+    milkProduction: float
+    milkSellingPrice: float
+    variableCosts: float
+
+class DecoupledSubsidiesDTO(BaseModel):
+    pGreen: float
+    pBasic: float
+
+class HolderInfoDTO(BaseModel):
+    holderAge: int
+    holderSuccessorsAge: int
+    holderSuccessors: int
+    holderFamilyMembers: int
+
+class AltitudeEnum(IntEnum):
+    MOUNTAINS = 1
+    HILLS = 2
+    PLAINS = 3
+
+class ValueToSPDTO(BaseModel):
+    farmCode: int
+    holderInfo: HolderInfoDTO
+    cod_RAGR: int
+    cod_RAGR3: int
+    technicalEconomicOrientation: int
+    altitude: AltitudeEnum
+    currentAssets: float
+    decoupledSubsidies: DecoupledSubsidiesDTO
+    crops: dict[str,CropDataDTO]
+    livestock: LivestockDTO
+
+class IntermediateValueFromLP(BaseModel):
+    farmId: int
+    averageHAPrice: float
+    previousAgriculturalLand: float
+    result: dict
